access_control_ui library
Classes
- AccessControl
- A widget that shows or hides its child based on access control checks.
- AccessControlModel
- A model representing access-related data for a user, such as roles, permissions, and subscription plan.
- AccessControlProvider
- Provides access control context (roles, permissions, subscription plans) to the entire widget tree.
- AccessControlUtils
- Utility class providing static methods to perform quick access control checks within the widget tree.
- AccessGuard
- A widget used to guard access to full screens or routes based on user roles, permissions, or subscription plans.